@@ -442,7 +442,8 @@ inspection_arguments = [1, 0, 1.2, 'abc', '1', '0', '1.2', '1/2', {1, 2, 3}, {'a
                         [(2, 5), (3, 2)], [1, 2, 3], [1, 0, 1, 0],
                         {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j,
                         b'2', b'a', bytearray(1), frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'}),
-                        (lambda x: x < 5), range(2), '(iter([1, 2, 3]))', '(iter(reversed([1, 2, 3])))',
+                        '(lambda x: x < 5)', 'range(2)', "enumerate('a')", '(iter([1, 2, 3]))',
+                        '(iter(reversed([1, 2, 3])))',
                         '(iter(range(5)))',
                         '(iter({1, 2, 3}))', "(iter('abc'))", '(iter((1, 2, 3)))', "(iter({'a': 1, 'b': 2}.items()))",
                         "(iter(zip((0, 1, 2), 'abc')))",
